
// Vertex Shader: vertexShader_PosColorXform
// Sets the position and color of a vertex.
//   The projection and modelview matrices are used to position the vertex.
//   It copies the color to "theColor" so that the fragment shader can access it.
#beginglsl VertexShader vertexShader_PosColorXform
#version 330 core    
layout (location = 0) in vec3 vertPos;	// Position in attribute location 0    
layout (location = 1) in vec3 vertColor;  // Color in attribute location 1    
out vec3 theColor;					// output a color to the fragment shader    
uniform mat4 projectionMatrix;		// The projection matrix    
uniform mat4 modelviewMatrix;		// The model-view matrix    
void main()    
{    
   gl_Position = projectionMatrix * modelviewMatrix * vec4(vertPos.x, vertPos.y, vertPos.z, 1.0);
   theColor = vertColor;
}
#endglsl

// Fragment Shader: fragmentShader_ColorOnly
// Set a general color using a fragment shader. (A "fragment" is a "pixel".)
//    The color value is passed in, obtained from the color(s) on the vertice(s).
//    Color values range from 0.0 to 1.0.
//    First three values are Red/Green/Blue (RGB).
//    Fourth color value (alpha) is 1.0, meaning there is no transparency.
#beginglsl FragmentShader fragmentShader_ColorOnly =
#version 330 core    
in vec3 theColor;		// Color value came from the vertex shader (smoothed)     
out vec4 FragColor;	// Color that will be used for the fragment    
void main()    
{    
   FragColor = vec4(theColor, 1.0f);   // Add alpha value of 1.0.    
}
#endglsl